define([
  './agents/agentsCtrl',
  './audit/agentsAuditCtrl',
  './configuration/agentConfigCtrl',
  './fim/agentsFimCtrl',
  './virustotal/agentsVirusTotalCtrl',
  './gdpr/agentsGdprCtrl',
  './general/agentsGeneralCtrl',
  './inventory/inventoryCtrl',
  './osquery/osqueryCtrl',
  './docker/agentsDockerCtrl',
  './overview/agentsOverviewCtrl',
  './pcidss/agentsPciCtrl',
  './policy-monitoring/agentsPolicyMonitoringCtrl',
  './scap/agentsOpenScapCtrl',
  './ciscat/agentsCiscatCtrl',
  './vulnerabilities/agentsVulnerabilitiesCtrl',
  './configuration-assessment/agentsConfigurationAssessmentsCtrl',
  './hipaa/agentsHipaaCtrl',
  './nist/agentsNistCtrl',
  './cve/agentsCveCtrl',
], function () {})
